==> nextcloud-app-tasks-0.9.6-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/fa.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "وظایف",
    "Due yesterday" : "تا دیروز",
    "Due today" : "تا امروز",
    "Due tomorrow" : "تا فردا",
    "Due on" : "سررسید",
    "Started yesterday" : "دیروز شروع شده است",
    "Starts today" : "امروز شروع شده است",
    "Starts tomorrow" : "فردا شروع می‌شود",
    "Started on" : "شروع شده از",
    "Yesterday" : "دیروز",
    "Today" : "امروز",
    "Tomorrow" : "فردا",
    "in %s" : "در %s",
    "%s ago" : "%s قبل",
    "seconds" : "ثانیه ها",
    "a minute" : "یک دقیقه",
    "%d minutes" : "%d دقیقه",
    "an hour" : "یک ساعت",
    "%d hours" : "%d ساعت",
    "a day" : "یک روز",
    "%d days" : "%d روز",
    "a month" : "یک ماه",
    "%d months" : "%dماه",
    "a year" : "یک سال",
    "%d years" : "%d سال",
    "week" : "هفته",
    "weeks" : "هفته",
    "day" : "روز",
    "days" : "روز ها",
    "hour" : "ساعت",
    "hours" : "ساعت ها",
    "minute" : "دقیقه",
    "minutes" : "دقیقه ها",
    "second" : "دومین",
    "Comment" : "نظر",
    "Add a comment" : "افزودن نظر",
    "Hidden" : "مخفی",
    "Sunday" : "یکشنبه",
    "Monday" : "دوشنبه",
    "Tuesday" : "سه شنبه",
    "Wednesday" : "چهارشنبه",
    "Thursday" : "پنجشنبه",
    "Friday" : "جمعه",
    "Saturday" : "شنبه",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n کار تکمیل شده"],
    "Hours" : "ساعت ها",
    "Minutes" : "دقایق",
    "Set due date" : "تعریف سر رسید",
    "high" : "زیاد",
    "medium" : "متوسط",
    "low" : "کم",
    "at the end" : "در انتها",
    "at the beginning" : "در آغاز",
    "Important" : "مهم",
    "Week" : "هفته",
    "All" : "همه",
    "Current" : "کنونی",
    "Completed" : "نکمیل شده",
    "Delete" : "حذف",
    "Cancel" : "لغو",
    "Edit" : "ویرایش",
    "Link" : "لینک",
    "Download" : "دانلود",
    "Save" : "ذخیره",
    "New List" : "لیست جدید",
    "Settings" : "تنظیمات",
    "Start of week" : "شروع هفته",
    "Default" : "پیش فرض",
    "Select categories..." : "انتخاب مجموعه...",
    "Loading the task..." : "بارگزاری کار...",
    "Task not found!" : "کار یافت نشد!"
},
"nplurals=1; plural=0;");

==> nextcloud-app-tasks-0.9.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/fa.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "وظایف",
    "Due yesterday" : "تا دیروز",
    "Due today" : "تا امروز",
    "Due tomorrow" : "تا فردا",
    "Due on" : "سررسید",
    "Started yesterday" : "دیروز شروع شده است",
    "Starts today" : "امروز شروع شده است",
    "Starts tomorrow" : "فردا شروع می‌شود",
    "Started on" : "شروع شده از",
    "Yesterday" : "دیروز",
    "Today" : "امروز",
    "Tomorrow" : "فردا",
    "in %s" : "در %s",
    "%s ago" : "%s قبل",
    "seconds" : "ثانیه ها",
    "a minute" : "یک دقیقه",
    "%d minutes" : "%d دقیقه",
    "an hour" : "یک ساعت",
    "%d hours" : "%d ساعت",
    "a day" : "یک روز",
    "%d days" : "%d روز",
    "a month" : "یک ماه",
    "%d months" : "%dماه",
    "a year" : "یک سال",
    "%d years" : "%d سال",
    "week" : "هفته",
    "weeks" : "هفته",
    "day" : "روز",
    "days" : "روز ها",
    "hour" : "ساعت",
    "hours" : "ساعت ها",
    "minute" : "دقیقه",
    "minutes" : "دقیقه ها",
    "second" : "دومین",
    "Comment" : "نظر",
    "Add a comment" : "افزودن نظر",
    "Hidden" : "مخفی",
    "Sunday" : "یکشنبه",
    "Monday" : "دوشنبه",
    "Tuesday" : "سه شنبه",
    "Wednesday" : "چهارشنبه",
    "Thursday" : "پنجشنبه",
    "Friday" : "جمعه",
    "Saturday" : "شنبه",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n کار تکمیل شده","%n کار تکمیل شده"],
    "Hours" : "ساعت ها",
    "Minutes" : "دقایق",
    "Set due date" : "تعریف سر رسید",
    "high" : "زیاد",
    "medium" : "متوسط",
    "low" : "کم",
    "at the end" : "در انتها",
    "at the beginning" : "در آغاز",
    "Important" : "مهم",
    "Week" : "هفته",
    "All" : "همه",
    "Current" : "کنونی",
    "Completed" : "نکمیل شده",
    "Delete" : "حذف",
    "Cancel" : "لغو",
    "Edit" : "ویرایش",
    "Link" : "لینک",
    "Download" : "دانلود",
    "Save" : "ذخیره",
    "New List" : "لیست جدید",
    "Settings" : "تنظیمات",
    "Start of week" : "شروع هفته",
    "Default" : "پیش فرض",
    "Select categories..." : "انتخاب مجموعه...",
    "Loading the task..." : "بارگزاری کار...",
    "Task not found!" : "کار یافت نشد!"
},
"nplurals=2; plural=(n > 1);");
